@@ -80,6 +80,31 @@ def queue_create(transport, request, name,
     return resp.deserialized_content
 
 
+def queue_update(transport, request, name, metadata, callback=None):
+    """Updates a queue's metadata using PATCH. API v1.1+ only
+
+    :param transport: Transport instance to use
+    :type transport: `transport.base.Transport`
+    :param request: Request instance ready to be sent.
+    :type request: `transport.request.Request`
+    :param name: Queue reference name.
+    :type name: `six.text_type`
+    :param metadata: Queue's metadata object. (>=v1.1)
+    :type metadata: `dict`
+    :param callback: Optional callable to use as callback.
+        If specified, this request will be sent asynchronously.
+        (IGNORED UNTIL ASYNC SUPPORT IS COMPLETE)
+    :type callback: Callable object.
+    """
+
+    request.operation = 'queue_update'
+    request.params['queue_name'] = name
+    request.content = json.dumps(metadata)
+
+    resp = transport.send(request)
+    return resp.deserialized_content
+
+
 def queue_exists(transport, request, name, callback=None):
     """Checks if the queue exists."""
     try:
