@@ -48,9 +48,52 @@ class OldDeleteQueue(cli.OldDeleteQueue):
     pass
 
 
-class ListQueues(cli.ListQueues):
+class ListQueues(command.Lister):
     """List available queues"""
-    pass
+
+    _description = _("List available queues")
+    log = logging.getLogger(__name__ + ".ListQueues")
+
+    def get_parser(self, prog_name):
+        parser = super(ListQueues, self).get_parser(prog_name)
+        parser.add_argument(
+            "--marker",
+            metavar="<queue_id>",
+            help="Queue's paging marker")
+        parser.add_argument(
+            "--limit",
+            metavar="<limit>",
+            help="Page size limit")
+        parser.add_argument(
+            "--detailed",
+            action="store_true",
+            help="If show detailed information of queue")
+        parser.add_argument(
+            "--with_count",
+            action="store_true",
+            help="If show amount information of queue")
+
+        return parser
+
+    def take_action(self, parsed_args):
+        client = _get_client(self, parsed_args)
+        kwargs = {}
+        columns = ["Name"]
+        if parsed_args.marker is not None:
+            kwargs["marker"] = parsed_args.marker
+        if parsed_args.limit is not None:
+            kwargs["limit"] = parsed_args.limit
+        if parsed_args.detailed is not None and parsed_args.detailed:
+            kwargs["detailed"] = parsed_args.detailed
+            columns.extend(["Metadata_Dict", "Href"])
+        if parsed_args.with_count is not None and parsed_args.with_count:
+            kwargs["with_count"] = parsed_args.with_count
+
+        data, count = client.queues(**kwargs)
+        if count:
+            print("Queues in total: %s" % count)
+        columns = tuple(columns)
+        return (columns, (utils.get_item_properties(s, columns) for s in data))
 
 
 class OldListQueues(cli.OldListQueues):
@@ -521,8 +564,8 @@ class UpdateSubscription(command.ShowOne):
                 'options': parsed_args.options}
 
         kwargs = {'id': parsed_args.subscription_id}
-        subscription = client.subscription(parsed_args.queue_name, kwargs,
-                                           auto_create=False)
+        subscription = client.subscription(parsed_args.queue_name,
+                                           auto_create=False, **kwargs)
 
         subscription.update(data)
 
